<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Settings extends CI_Controller {

	function __construct()
    {
        parent::__construct();
        $this->load->model('user_db');
        $this->load->model('category_db');
        $this->load->model('product_db');
        $this->load->model('barcode_model');
        $this->load->library('session');
        $this->load->library('form_validation');
        $this->load->helper('form');
    }

    public function index()
    {
        $data = array(
            'benutzer_array' => $this->user_db->getAllUsers(),
            'kategorien_array' => $this->category_db->selectAllCategories(),
            'units_array' => $this->category_db->selectAllUnits(),
            'products_barcode' => $this->barcode_model->getAllProducts()
        );

        $this->load->view('templates/header', $data);
        $this->load->view('modals/add_user_modal');
        $this->load->view('modals/user_pwchange_modal');
        $this->load->view('modals/add_product_barcode_modal');
        $this->load->view('settings');
    }

    public function adduser()
    {
        $benutzername_post = $this->input->post('benutzername', true);
        $passwort_post = $this->input->post('passwort');

        if(!empty($benutzername_post) || !empty($passwort_post))
        {
            if ($this->user_db->checkUsername($benutzername_post) == 0) 
            {
                $result = $this->user_db->createUser($benutzername_post, password_hash($passwort_post, PASSWORD_BCRYPT));
                redirect('settings/index?Status='.$result);
            }
            else
            {
                echo "Benutzer bereits vorhanden!";
                return;
            }
        }
    }

    /**
    * Remove an User
    * @since 0.7.0
    */
    public function removeuser($id){
        //- Check if user have inserts
        if ($this->product_db->userhasproducts($id) != 0) {
            redirect('settings/index?Status=BenutzerHatProdukte');
        }
        // check if user is admin account
        if ($id == 1) {
            redirect('settings/index?Status=BenutzerNichtGeloescht');
        } else {
            $result = $this->user_db->removeUserById($id);
            if ($this->session->userdata('userid') == $id) {
                redirect('login/logout');
            }
            redirect('settings/index?Status=BenutzerGeloescht');
        }
    }

    /**
     * Update users password
     * @since 0.7.0
     */
     public function updatepassword(){
        $passwort_post = $this->input->post('pass_new');
        $memberid_post = $this->input->post('idvalue');
        $this->load->library('form_validation');
        $this->load->helper('form');

        $this->form_validation->set_rules('pass_new', 'Passwort', 'required');
        $this->form_validation->set_rules('pass_conf', 'Passwort wiederholen', 'required|matches[pass_new]');

        if($this->form_validation->run() == FALSE){
            $data['error01'] = "Fehler, bitte wiederholen!";
            $this->load->view('templates/header');
            $this->load->view('errors/witt/default_error', $data);
            $this->load->view('templates/footer');
            
        } else {
            if ($memberid_post) {
                if($this->user_db->updatePassword($memberid_post, password_hash($passwort_post, PASSWORD_BCRYPT))){
                    redirect('settings/index?Status=PasswortGeaendert');
                } else {
                    redirect('settings/index?Status=PasswortWechselFehlgeschlagen');
                }
            }
        }
     }

    /**
     * Create Product with barcode
     * 
     * @since 0.8.0
     * @author Simon<>
    */
    public function addBarcodeProduct(){
        if($this->barcode_model->createProduct($this->input->post(NULL, TRUE))){
            redirect('settings/index');
        }
    }

    public function removeBarcodeProduct($id){
        if(isset($id)){
            if($this->barcode_model->removeProductById($id)){
                redirect('settings/index');
            }
        }
    }
}
